==> zio-aws-ecs_2.13-5.17.122.1-sources.jar: zio/aws/ecs/model/PlacementStrategy.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PlacementStrategy(
    `type`: Option[zio.aws.ecs.model.PlacementStrategyType] = None,
    field: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PlacementStrategy = {
    import PlacementStrategy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PlacementStrategy
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(field.map(value => value: java.lang.String))(_.field)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.PlacementStrategy.ReadOnly =
    zio.aws.ecs.model.PlacementStrategy.wrap(buildAwsValue())
}
object PlacementStrategy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PlacementStrategy = zio.aws.ecs.model
      .PlacementStrategy(`type`.map(value => value), field.map(value => value))
    def `type`: Option[zio.aws.ecs.model.PlacementStrategyType]
    def field: Option[String]
    def getType: ZIO[Any, AwsError, zio.aws.ecs.model.PlacementStrategyType] =
      AwsError.unwrapOptionField("type", `type`)
    def getField: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("field", field)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ) extends zio.aws.ecs.model.PlacementStrategy.ReadOnly {
    override val `type`: Option[zio.aws.ecs.model.PlacementStrategyType] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.ecs.model.PlacementStrategyType.wrap(value))
    override val field: Option[String] =
      scala.Option(impl.field()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ): zio.aws.ecs.model.PlacementStrategy.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-6.20.97.2-sources.jar: zio/aws/ecs/model/PlacementStrategy.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PlacementStrategy(
    `type`: Optional[zio.aws.ecs.model.PlacementStrategyType] = Optional.Absent,
    field: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.PlacementStrategy = {
    import PlacementStrategy.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.PlacementStrategy
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(field.map(value => value: java.lang.String))(_.field)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.PlacementStrategy.ReadOnly =
    zio.aws.ecs.model.PlacementStrategy.wrap(buildAwsValue())
}
object PlacementStrategy {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.PlacementStrategy = zio.aws.ecs.model
      .PlacementStrategy(`type`.map(value => value), field.map(value => value))
    def `type`: Optional[zio.aws.ecs.model.PlacementStrategyType]
    def field: Optional[String]
    def getType: ZIO[Any, AwsError, zio.aws.ecs.model.PlacementStrategyType] =
      AwsError.unwrapOptionField("type", `type`)
    def getField: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("field", field)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ) extends zio.aws.ecs.model.PlacementStrategy.ReadOnly {
    override val `type`: Optional[zio.aws.ecs.model.PlacementStrategyType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.ecs.model.PlacementStrategyType.wrap(value))
    override val field: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.field())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.PlacementStrategy
  ): zio.aws.ecs.model.PlacementStrategy.ReadOnly = new Wrapper(impl)
}
